.. include:: ../references.txt

.. _user_guide:

==========
User guide
==========

.. toctree::
    :hidden:
    :titlesonly:

    package
    howto
    model-gallery/index
    Gammapy recipes <https://gammapy.github.io/gammapy-recipes>
    references

.. grid:: 1 2 2 2
   :gutter: 2

   .. grid-item-card::
      :text-align: center
      :columns: 12 6 6 6
      :shadow: md

      :octicon:`light-bulb;4em`

      **Fundamental concepts**

      An overview of the main concepts in Gammapy package.

      +++

      .. button-ref:: package_structure
         :ref-type: ref
         :click-parent:
         :color: secondary
         :expand:

         To the package overview

   .. grid-item-card::
      :text-align: center
      :columns: 12 6 6 6
      :shadow: md

      :octicon:`command-palette;4em`

      **How To**

      A short “frequently asked question” entries for Gammapy.

      +++

      .. button-ref:: how_to
         :ref-type: ref
         :click-parent:
         :color: secondary
         :expand:

         To the How To

   .. grid-item-card::
      :text-align: center
      :columns: 12 6 6 6
      :shadow: md

      :octicon:`file-media;4em`

      **Model gallery**

      Gammapy provides a large choice of spatial, spectral and temporal models.

      +++

      .. button-ref:: model-gallery
         :ref-type: ref
         :click-parent:
         :color: secondary
         :expand:

         To the model gallery

   .. grid-item-card::
      :text-align: center
      :columns: 12 6 6 6
      :shadow: md

      :octicon:`number;4em`

      **Gammapy recipes**

      A collection of **user contributed** notebooks covering aspects not present in the official tutorials.

      +++

      .. button-link:: https://gammapy.github.io/gammapy-recipes
         :click-parent:
         :color: secondary
         :expand:

         To the recipes
